@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -44,6 +44,7 @@ import com.google.api.client.http.GenericUrl;
 import com.google.api.client.http.HttpResponse;
 import com.google.api.client.http.InputStreamContent;
 import com.google.api.services.drive.Drive;
+import com.google.api.services.drive.Drive.Files.Update;
 import com.google.api.services.drive.model.Change;
 import com.google.api.services.drive.model.FileList;
 import com.openexchange.annotation.NonNull;
@@ -290,7 +291,6 @@ public class GoogleDriveFileAccess extends AbstractGoogleDriveAccess implements
 
                 // Create patch file
                 com.google.api.services.drive.model.File patch = new com.google.api.services.drive.model.File();
-                GoogleDriveUtil.setParentFolder(patch, destId);
 
                 if (null != update) {
                     if (isFileNameChanged(update, modifiedFields, srcFile)) {
@@ -299,13 +299,16 @@ public class GoogleDriveFileAccess extends AbstractGoogleDriveAccess implements
                     }
                 }
 
-                String fileName = getFileName(drive, destFolder, name);
+                String fileName = getFileName(drive, destId, name);
                 if (false == name.equals(fileName)) {
                     patch.setName(fileName);
                 }
 
                 // Patch the file
-                com.google.api.services.drive.model.File patchedFile = drive.files().update(id, patch).execute();
+                Update update = drive.files().update(id, patch);
+                update.setRemoveParents(GoogleDriveUtil.getParentFolders(srcFile));
+                update.setAddParents(destId);
+                com.google.api.services.drive.model.File patchedFile = update.execute();
 
                 return new IDTuple(destFolder, patchedFile.getId());
 
